# FastRTC

## The Real-Time Communication Library for Python

Turn any python function into a real-time audio and video stream over WebRTC or WebSockets. Now with the [Kroko-ASR TTS Model](https://huggingface.co/Banafo/Kroko-ASR)!

### Installation

```bash
pip install fastrtc-kroko
```

